# -*- coding: utf-8 -*-
from setuphelpers import *
import platform
import json

# Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_name_x64 = 'Regshot-x64-Unicode.exe'
bin_name_x86 = 'Regshot-x86-Unicode.exe'
app_name = 'Regshot'
app_path = makepath(programfiles32,app_name)
app_bin_path_x64 = makepath(app_path,bin_name_x64)
app_bin_path_x86 = makepath(app_path,bin_name_x86)


def install():
    # Installing the package
    if isdir(app_path):
        remove_tree(app_path)
        copytree2(app_name,app_path)
    else:
        copytree2(app_name,app_path)

    if iswin64():
        #create_desktop_shortcut(app_name,app_bin_path_x64)
        create_programs_menu_shortcut(app_name,app_bin_path_x64)
    else:
        #create_desktop_shortcut(app_name,app_bin_path_x86)
        create_programs_menu_shortcut(app_name,app_bin_path_x86)


def uninstall():
    remove_tree(app_path)
    #remove_desktop_shortcut(app_name)
    remove_programs_menu_shortcut(app_name)


def update_package():
    # Declaring local variables
    result = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()

    if isdir('Regshot'):
        remove_tree('Regshot')
    windows_release = json.loads(wgets('https://sourceforge.net/projects/regshot/best_release.json', proxies=proxies))['platform_releases']['windows']
    filename = windows_release['filename'].split('/')[-1]
    url_release = windows_release['url']

    """ url_release = 'https://sourceforge.net/projects/regshot/files/regshot/1.9.1-beta/Regshot-1.9.1-beta_r321.7z/download'
    filename = url_release.split('/')[-2] """

    if not isfile(filename):
        wget(url_release,filename, proxies=proxies)

    path7z = makepath(programfiles,'7-Zip','7z.exe')

    run('"%s" e %s -o%s' % (path7z,filename,app_name))

    if isfile(filename):
        remove_file(filename)

    version = get_file_properties(makepath(app_name,bin_name_x86))['ProductVersion'].split(' ')[0]

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        result = True
    control.version = '%s-%s' % (Version(version), control.version.split('-', 1)[-1])
    #control.set_software_version(version)
    control.save_control_to_wapt()

    # Deleting outdated binaries
    remove_outdated_binaries(version)

    # Validating update-package-sources
    return result



def get_proxies():
    r"""Return system proxy with the urllib python library

    >>> get_proxies()
    {'http': 'http://srvproxy.ad.domain.lan:8080',
    'https': 'http://srvproxy.ad.domain.lan:8080'}

    """
    if platform.python_version_tuple()[0] == '3':
        from urllib.request import getproxies
    else:
        from urllib import getproxies
    return getproxies()


def get_proxies_from_wapt_console():
    r"""Return proxy information from the current user WAPT console

    >>> get_proxies_from_wapt_console()
    {'http': 'http://srvproxy.ad.domain.lan:8080',
    'https': 'http://srvproxy.ad.domain.lan:8080'}

    """
    proxies = {}
    if platform.system() == 'Windows':
        waptconsole_ini_path = makepath(user_local_appdata(), 'waptconsole', 'waptconsole.ini')
    else:
        waptconsole_ini_path = makepath(user_home_directory(), '.config', 'waptconsole', 'waptconsole.ini')
    if isfile(waptconsole_ini_path):
        proxy_wapt = inifile_readstring(waptconsole_ini_path, 'global', 'http_proxy')
        if proxy_wapt:
            proxies = {'http': proxy_wapt, 'https': proxy_wapt}
    return proxies

